BackPACK
====================================

BackPACK is a library built on top of PyTorch
to extract more information from a backward pass.

.. code:: bash

	pip install backpack-for-pytorch

For a quick overview of the features, check `backpack.pt <http://www.backpack.pt>`_.
The code lives on `Github <http://www.github.com/f-dangel/backpack>`_.


.. toctree::
	:maxdepth: 2
	:caption: Getting started

	main-api
	basic_usage/example_all_in_one

.. toctree::
	:maxdepth: 2
	:caption: Backpack

	supported-layers
	extensions
	good-to-know
	use_cases/index


